
import sys
if sys.version_info >= (3, 8):
    from typing import Protocol
else:
    from typing_extensions import Protocol

import java.io
import java.util
import jpype
import org.hipparchus.analysis
import typing



class AbstractCurveFitter:
    def __init__(self): ...
    def fit(self, collection: typing.Union[java.util.Collection['WeightedObservedPoint'], typing.Sequence['WeightedObservedPoint'], typing.Set['WeightedObservedPoint']]) -> typing.MutableSequence[float]: ...

class WeightedObservedPoint(java.io.Serializable):
    def __init__(self, double: float, double2: float, double3: float): ...
    def getWeight(self) -> float: ...
    def getX(self) -> float: ...
    def getY(self) -> float: ...

class WeightedObservedPoints(java.io.Serializable):
    def __init__(self): ...
    @typing.overload
    def add(self, double: float, double2: float) -> None: ...
    @typing.overload
    def add(self, double: float, double2: float, double3: float) -> None: ...
    @typing.overload
    def add(self, weightedObservedPoint: WeightedObservedPoint) -> None: ...
    def clear(self) -> None: ...
    def toList(self) -> java.util.List[WeightedObservedPoint]: ...

class GaussianCurveFitter(AbstractCurveFitter):
    @staticmethod
    def create() -> 'GaussianCurveFitter': ...
    def withMaxIterations(self, int: int) -> 'GaussianCurveFitter': ...
    def withStartPoint(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> 'GaussianCurveFitter': ...
    class ParameterGuesser:
        def __init__(self, collection: typing.Union[java.util.Collection[WeightedObservedPoint], typing.Sequence[WeightedObservedPoint], typing.Set[WeightedObservedPoint]]): ...
        def guess(self) -> typing.MutableSequence[float]: ...

class HarmonicCurveFitter(AbstractCurveFitter):
    @staticmethod
    def create() -> 'HarmonicCurveFitter': ...
    def withMaxIterations(self, int: int) -> 'HarmonicCurveFitter': ...
    def withStartPoint(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> 'HarmonicCurveFitter': ...
    class ParameterGuesser:
        def __init__(self, collection: typing.Union[java.util.Collection[WeightedObservedPoint], typing.Sequence[WeightedObservedPoint], typing.Set[WeightedObservedPoint]]): ...
        def guess(self) -> typing.MutableSequence[float]: ...

class PolynomialCurveFitter(AbstractCurveFitter):
    @staticmethod
    def create(int: int) -> 'PolynomialCurveFitter': ...
    def withMaxIterations(self, int: int) -> 'PolynomialCurveFitter': ...
    def withStartPoint(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> 'PolynomialCurveFitter': ...

class SimpleCurveFitter(AbstractCurveFitter):
    @staticmethod
    def create(parametricUnivariateFunction: org.hipparchus.analysis.ParametricUnivariateFunction, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> 'SimpleCurveFitter': ...
    def withMaxIterations(self, int: int) -> 'SimpleCurveFitter': ...
    def withStartPoint(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> 'SimpleCurveFitter': ...


class __module_protocol__(Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.hipparchus.fitting")``.

    AbstractCurveFitter: typing.Type[AbstractCurveFitter]
    GaussianCurveFitter: typing.Type[GaussianCurveFitter]
    HarmonicCurveFitter: typing.Type[HarmonicCurveFitter]
    PolynomialCurveFitter: typing.Type[PolynomialCurveFitter]
    SimpleCurveFitter: typing.Type[SimpleCurveFitter]
    WeightedObservedPoint: typing.Type[WeightedObservedPoint]
    WeightedObservedPoints: typing.Type[WeightedObservedPoints]
