
import sys
if sys.version_info >= (3, 8):
    from typing import Protocol
else:
    from typing_extensions import Protocol

import java.io
import java.lang
import java.util
import java.util.function
import jpype
import org.hipparchus.linear
import org.hipparchus.random
import org.hipparchus.stat.descriptive.moment
import org.hipparchus.stat.descriptive.rank
import org.hipparchus.stat.descriptive.summary
import org.hipparchus.stat.descriptive.vector
import org.hipparchus.util
import typing



_AggregatableStatistic__T = typing.TypeVar('_AggregatableStatistic__T')  # <T>
class AggregatableStatistic(typing.Generic[_AggregatableStatistic__T]):
    @typing.overload
    def aggregate(self, t: _AggregatableStatistic__T) -> None: ...
    @typing.overload
    def aggregate(self, iterable: typing.Union[java.lang.Iterable[_AggregatableStatistic__T], typing.Sequence[_AggregatableStatistic__T], typing.Set[_AggregatableStatistic__T], typing.Callable[[], java.util.Iterator[typing.Any]]]) -> None: ...
    @typing.overload
    def aggregate(self, *t: _AggregatableStatistic__T) -> None: ...

class StatisticalMultivariateSummary:
    def getCovariance(self) -> org.hipparchus.linear.RealMatrix: ...
    def getDimension(self) -> int: ...
    def getGeometricMean(self) -> typing.MutableSequence[float]: ...
    def getMax(self) -> typing.MutableSequence[float]: ...
    def getMean(self) -> typing.MutableSequence[float]: ...
    def getMin(self) -> typing.MutableSequence[float]: ...
    def getN(self) -> int: ...
    def getStandardDeviation(self) -> typing.MutableSequence[float]: ...
    def getSum(self) -> typing.MutableSequence[float]: ...
    def getSumLog(self) -> typing.MutableSequence[float]: ...
    def getSumSq(self) -> typing.MutableSequence[float]: ...

class StatisticalSummary:
    @typing.overload
    @staticmethod
    def aggregate(iterable: typing.Union[java.lang.Iterable['StatisticalSummary'], typing.Sequence['StatisticalSummary'], typing.Set['StatisticalSummary'], typing.Callable[[], java.util.Iterator[typing.Any]]]) -> 'StatisticalSummary': ...
    @typing.overload
    @staticmethod
    def aggregate(*statisticalSummary: 'StatisticalSummary') -> 'StatisticalSummary': ...
    def getMax(self) -> float: ...
    def getMean(self) -> float: ...
    def getMin(self) -> float: ...
    def getN(self) -> int: ...
    def getStandardDeviation(self) -> float: ...
    def getSum(self) -> float: ...
    def getVariance(self) -> float: ...

class StorelessMultivariateStatistic:
    def clear(self) -> None: ...
    def getDimension(self) -> int: ...
    def getN(self) -> int: ...
    def getResult(self) -> typing.MutableSequence[float]: ...
    def increment(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...

class UnivariateStatistic(org.hipparchus.util.MathArrays.Function):
    def copy(self) -> 'UnivariateStatistic': ...
    @typing.overload
    def evaluate(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], int: int, int2: int) -> float: ...
    @typing.overload
    def evaluate(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> float: ...

class WeightedEvaluation:
    @typing.overload
    def evaluate(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], doubleArray2: typing.Union[typing.List[float], jpype.JArray], int: int, int2: int) -> float: ...
    @typing.overload
    def evaluate(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], doubleArray2: typing.Union[typing.List[float], jpype.JArray]) -> float: ...

class AbstractUnivariateStatistic(UnivariateStatistic):
    def copy(self) -> UnivariateStatistic: ...
    @typing.overload
    def evaluate(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], int: int, int2: int) -> float: ...
    @typing.overload
    def evaluate(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> float: ...
    @typing.overload
    def evaluate(self) -> float: ...
    def getData(self) -> typing.MutableSequence[float]: ...
    @typing.overload
    def setData(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    @typing.overload
    def setData(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], int: int, int2: int) -> None: ...

class DescriptiveStatistics(StatisticalSummary, java.util.function.DoubleConsumer, java.io.Serializable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]): ...
    @typing.overload
    def __init__(self, int: int): ...
    def accept(self, double: float) -> None: ...
    def addValue(self, double: float) -> None: ...
    def apply(self, univariateStatistic: UnivariateStatistic) -> float: ...
    def clear(self) -> None: ...
    def copy(self) -> 'DescriptiveStatistics': ...
    def getElement(self, int: int) -> float: ...
    def getGeometricMean(self) -> float: ...
    def getKurtosis(self) -> float: ...
    def getMax(self) -> float: ...
    def getMean(self) -> float: ...
    def getMin(self) -> float: ...
    def getN(self) -> int: ...
    def getPercentile(self, double: float) -> float: ...
    def getPopulationVariance(self) -> float: ...
    def getQuadraticMean(self) -> float: ...
    def getSkewness(self) -> float: ...
    def getSortedValues(self) -> typing.MutableSequence[float]: ...
    def getStandardDeviation(self) -> float: ...
    def getSum(self) -> float: ...
    def getSumOfSquares(self) -> float: ...
    def getValues(self) -> typing.MutableSequence[float]: ...
    def getVariance(self) -> float: ...
    def getWindowSize(self) -> int: ...
    def removeMostRecentValue(self) -> None: ...
    def replaceMostRecentValue(self, double: float) -> float: ...
    def setWindowSize(self, int: int) -> None: ...
    def toString(self) -> str: ...

class MultivariateSummaryStatistics(StatisticalMultivariateSummary, java.io.Serializable):
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, boolean: bool): ...
    def addValue(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def clear(self) -> None: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getCovariance(self) -> org.hipparchus.linear.RealMatrix: ...
    def getDimension(self) -> int: ...
    def getGeometricMean(self) -> typing.MutableSequence[float]: ...
    def getMax(self) -> typing.MutableSequence[float]: ...
    def getMean(self) -> typing.MutableSequence[float]: ...
    def getMin(self) -> typing.MutableSequence[float]: ...
    def getN(self) -> int: ...
    def getStandardDeviation(self) -> typing.MutableSequence[float]: ...
    def getSum(self) -> typing.MutableSequence[float]: ...
    def getSumLog(self) -> typing.MutableSequence[float]: ...
    def getSumSq(self) -> typing.MutableSequence[float]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class StatisticalSummaryValues(java.io.Serializable, StatisticalSummary):
    def __init__(self, double: float, double2: float, long: int, double3: float, double4: float, double5: float): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getMax(self) -> float: ...
    def getMean(self) -> float: ...
    def getMin(self) -> float: ...
    def getN(self) -> int: ...
    def getStandardDeviation(self) -> float: ...
    def getSum(self) -> float: ...
    def getVariance(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class StorelessUnivariateStatistic(UnivariateStatistic, java.util.function.DoubleConsumer):
    def accept(self, double: float) -> None: ...
    def clear(self) -> None: ...
    def copy(self) -> 'StorelessUnivariateStatistic': ...
    @typing.overload
    def evaluate(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], int: int, int2: int) -> float: ...
    @typing.overload
    def evaluate(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> float: ...
    def getN(self) -> int: ...
    def getResult(self) -> float: ...
    def increment(self, double: float) -> None: ...
    @typing.overload
    def incrementAll(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    @typing.overload
    def incrementAll(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], int: int, int2: int) -> None: ...

class StreamingStatistics(StatisticalSummary, AggregatableStatistic['StreamingStatistics'], java.util.function.DoubleConsumer, java.io.Serializable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, randomGenerator: org.hipparchus.random.RandomGenerator): ...
    def accept(self, double: float) -> None: ...
    def addValue(self, double: float) -> None: ...
    @typing.overload
    def aggregate(self, iterable: typing.Union[java.lang.Iterable[typing.Any], typing.Sequence[typing.Any], typing.Set[typing.Any], typing.Callable[[], java.util.Iterator[typing.Any]]]) -> None: ...
    @typing.overload
    def aggregate(self, *t: typing.Any) -> None: ...
    @typing.overload
    def aggregate(self, streamingStatistics: 'StreamingStatistics') -> None: ...
    @staticmethod
    def builder() -> 'StreamingStatistics.StreamingStatisticsBuilder': ...
    def clear(self) -> None: ...
    def copy(self) -> 'StreamingStatistics': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getGeometricMean(self) -> float: ...
    def getMax(self) -> float: ...
    def getMean(self) -> float: ...
    def getMedian(self) -> float: ...
    def getMin(self) -> float: ...
    def getN(self) -> int: ...
    def getPercentile(self, double: float) -> float: ...
    def getPopulationVariance(self) -> float: ...
    def getQuadraticMean(self) -> float: ...
    def getSecondMoment(self) -> float: ...
    def getStandardDeviation(self) -> float: ...
    def getSum(self) -> float: ...
    def getSumOfLogs(self) -> float: ...
    def getSumOfSquares(self) -> float: ...
    def getSummary(self) -> StatisticalSummary: ...
    def getVariance(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    class StreamingStatisticsBuilder:
        def __init__(self): ...
        def build(self) -> 'StreamingStatistics': ...
        def extrema(self, boolean: bool) -> 'StreamingStatistics.StreamingStatisticsBuilder': ...
        def moments(self, boolean: bool) -> 'StreamingStatistics.StreamingStatisticsBuilder': ...
        def percentiles(self, double: float, randomGenerator: org.hipparchus.random.RandomGenerator) -> 'StreamingStatistics.StreamingStatisticsBuilder': ...
        def sumOfLogs(self, boolean: bool) -> 'StreamingStatistics.StreamingStatisticsBuilder': ...
        def sumOfSquares(self, boolean: bool) -> 'StreamingStatistics.StreamingStatisticsBuilder': ...

class AbstractStorelessUnivariateStatistic(StorelessUnivariateStatistic):
    def __init__(self): ...
    def clear(self) -> None: ...
    def copy(self) -> StorelessUnivariateStatistic: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getResult(self) -> float: ...
    def hashCode(self) -> int: ...
    def increment(self, double: float) -> None: ...
    def toString(self) -> str: ...


class __module_protocol__(Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.hipparchus.stat.descriptive")``.

    AbstractStorelessUnivariateStatistic: typing.Type[AbstractStorelessUnivariateStatistic]
    AbstractUnivariateStatistic: typing.Type[AbstractUnivariateStatistic]
    AggregatableStatistic: typing.Type[AggregatableStatistic]
    DescriptiveStatistics: typing.Type[DescriptiveStatistics]
    MultivariateSummaryStatistics: typing.Type[MultivariateSummaryStatistics]
    StatisticalMultivariateSummary: typing.Type[StatisticalMultivariateSummary]
    StatisticalSummary: typing.Type[StatisticalSummary]
    StatisticalSummaryValues: typing.Type[StatisticalSummaryValues]
    StorelessMultivariateStatistic: typing.Type[StorelessMultivariateStatistic]
    StorelessUnivariateStatistic: typing.Type[StorelessUnivariateStatistic]
    StreamingStatistics: typing.Type[StreamingStatistics]
    UnivariateStatistic: typing.Type[UnivariateStatistic]
    WeightedEvaluation: typing.Type[WeightedEvaluation]
    moment: org.hipparchus.stat.descriptive.moment.__module_protocol__
    rank: org.hipparchus.stat.descriptive.rank.__module_protocol__
    summary: org.hipparchus.stat.descriptive.summary.__module_protocol__
    vector: org.hipparchus.stat.descriptive.vector.__module_protocol__
