
import sys
if sys.version_info >= (3, 8):
    from typing import Protocol
else:
    from typing_extensions import Protocol

import java.io
import jpype
import org.hipparchus.linear
import typing



class MultipleLinearRegression:
    def estimateRegressandVariance(self) -> float: ...
    def estimateRegressionParameters(self) -> typing.MutableSequence[float]: ...
    def estimateRegressionParametersStandardErrors(self) -> typing.MutableSequence[float]: ...
    def estimateRegressionParametersVariance(self) -> typing.MutableSequence[typing.MutableSequence[float]]: ...
    def estimateResiduals(self) -> typing.MutableSequence[float]: ...

class RegressionResults(java.io.Serializable):
    def __init__(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], doubleArray2: typing.Union[typing.List[typing.MutableSequence[float]], jpype.JArray], boolean: bool, long: int, int: int, double3: float, double4: float, double5: float, boolean2: bool, boolean3: bool): ...
    def getAdjustedRSquared(self) -> float: ...
    def getCovarianceOfParameters(self, int: int, int2: int) -> float: ...
    def getErrorSumSquares(self) -> float: ...
    def getMeanSquareError(self) -> float: ...
    def getN(self) -> int: ...
    def getNumberOfParameters(self) -> int: ...
    def getParameterEstimate(self, int: int) -> float: ...
    def getParameterEstimates(self) -> typing.MutableSequence[float]: ...
    def getRSquared(self) -> float: ...
    def getRegressionSumSquares(self) -> float: ...
    def getStdErrorOfEstimate(self, int: int) -> float: ...
    def getStdErrorOfEstimates(self) -> typing.MutableSequence[float]: ...
    def getTotalSumSquares(self) -> float: ...
    def hasIntercept(self) -> bool: ...

class UpdatingMultipleLinearRegression:
    def addObservation(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], double2: float) -> None: ...
    def addObservations(self, doubleArray: typing.Union[typing.List[typing.MutableSequence[float]], jpype.JArray], doubleArray2: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def clear(self) -> None: ...
    def getN(self) -> int: ...
    def hasIntercept(self) -> bool: ...
    @typing.overload
    def regress(self) -> RegressionResults: ...
    @typing.overload
    def regress(self, intArray: typing.Union[typing.List[int], jpype.JArray]) -> RegressionResults: ...

class AbstractMultipleLinearRegression(MultipleLinearRegression):
    def __init__(self): ...
    def estimateErrorVariance(self) -> float: ...
    def estimateRegressandVariance(self) -> float: ...
    def estimateRegressionParameters(self) -> typing.MutableSequence[float]: ...
    def estimateRegressionParametersStandardErrors(self) -> typing.MutableSequence[float]: ...
    def estimateRegressionParametersVariance(self) -> typing.MutableSequence[typing.MutableSequence[float]]: ...
    def estimateRegressionStandardError(self) -> float: ...
    def estimateResiduals(self) -> typing.MutableSequence[float]: ...
    def isNoIntercept(self) -> bool: ...
    def newSampleData(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], int: int, int2: int) -> None: ...
    def setNoIntercept(self, boolean: bool) -> None: ...

class MillerUpdatingRegression(UpdatingMultipleLinearRegression):
    @typing.overload
    def __init__(self, int: int, boolean: bool): ...
    @typing.overload
    def __init__(self, int: int, boolean: bool, double: float): ...
    def addObservation(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], double2: float) -> None: ...
    def addObservations(self, doubleArray: typing.Union[typing.List[typing.MutableSequence[float]], jpype.JArray], doubleArray2: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def clear(self) -> None: ...
    def getDiagonalOfHatMatrix(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> float: ...
    def getN(self) -> int: ...
    def getOrderOfRegressors(self) -> typing.MutableSequence[int]: ...
    def getPartialCorrelations(self, int: int) -> typing.MutableSequence[float]: ...
    def hasIntercept(self) -> bool: ...
    @typing.overload
    def regress(self) -> RegressionResults: ...
    @typing.overload
    def regress(self, int: int) -> RegressionResults: ...
    @typing.overload
    def regress(self, intArray: typing.Union[typing.List[int], jpype.JArray]) -> RegressionResults: ...

class SimpleRegression(java.io.Serializable, UpdatingMultipleLinearRegression):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, boolean: bool): ...
    @typing.overload
    def addData(self, double: float, double2: float) -> None: ...
    @typing.overload
    def addData(self, doubleArray: typing.Union[typing.List[typing.MutableSequence[float]], jpype.JArray]) -> None: ...
    def addObservation(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], double2: float) -> None: ...
    def addObservations(self, doubleArray: typing.Union[typing.List[typing.MutableSequence[float]], jpype.JArray], doubleArray2: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def append(self, simpleRegression: 'SimpleRegression') -> None: ...
    def clear(self) -> None: ...
    def getIntercept(self) -> float: ...
    def getInterceptStdErr(self) -> float: ...
    def getMeanSquareError(self) -> float: ...
    def getN(self) -> int: ...
    def getR(self) -> float: ...
    def getRSquare(self) -> float: ...
    def getRegressionSumSquares(self) -> float: ...
    def getSignificance(self) -> float: ...
    def getSlope(self) -> float: ...
    @typing.overload
    def getSlopeConfidenceInterval(self) -> float: ...
    @typing.overload
    def getSlopeConfidenceInterval(self, double: float) -> float: ...
    def getSlopeStdErr(self) -> float: ...
    def getSumOfCrossProducts(self) -> float: ...
    def getSumSquaredErrors(self) -> float: ...
    def getTotalSumSquares(self) -> float: ...
    def getXSumSquares(self) -> float: ...
    def hasIntercept(self) -> bool: ...
    def predict(self, double: float) -> float: ...
    @typing.overload
    def regress(self) -> RegressionResults: ...
    @typing.overload
    def regress(self, intArray: typing.Union[typing.List[int], jpype.JArray]) -> RegressionResults: ...
    @typing.overload
    def removeData(self, double: float, double2: float) -> None: ...
    @typing.overload
    def removeData(self, doubleArray: typing.Union[typing.List[typing.MutableSequence[float]], jpype.JArray]) -> None: ...

class GLSMultipleLinearRegression(AbstractMultipleLinearRegression):
    def __init__(self): ...
    @typing.overload
    def newSampleData(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], int: int, int2: int) -> None: ...
    @typing.overload
    def newSampleData(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], doubleArray2: typing.Union[typing.List[typing.MutableSequence[float]], jpype.JArray], doubleArray3: typing.Union[typing.List[typing.MutableSequence[float]], jpype.JArray]) -> None: ...

class OLSMultipleLinearRegression(AbstractMultipleLinearRegression):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float): ...
    def calculateAdjustedRSquared(self) -> float: ...
    def calculateHat(self) -> org.hipparchus.linear.RealMatrix: ...
    def calculateRSquared(self) -> float: ...
    def calculateResidualSumOfSquares(self) -> float: ...
    def calculateTotalSumOfSquares(self) -> float: ...
    @typing.overload
    def newSampleData(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], doubleArray2: typing.Union[typing.List[typing.MutableSequence[float]], jpype.JArray]) -> None: ...
    @typing.overload
    def newSampleData(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], int: int, int2: int) -> None: ...


class __module_protocol__(Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.hipparchus.stat.regression")``.

    AbstractMultipleLinearRegression: typing.Type[AbstractMultipleLinearRegression]
    GLSMultipleLinearRegression: typing.Type[GLSMultipleLinearRegression]
    MillerUpdatingRegression: typing.Type[MillerUpdatingRegression]
    MultipleLinearRegression: typing.Type[MultipleLinearRegression]
    OLSMultipleLinearRegression: typing.Type[OLSMultipleLinearRegression]
    RegressionResults: typing.Type[RegressionResults]
    SimpleRegression: typing.Type[SimpleRegression]
    UpdatingMultipleLinearRegression: typing.Type[UpdatingMultipleLinearRegression]
